import * as acmpca from '../../aws-acmpca';
import { Construct } from 'constructs';
import { ICertificate } from './certificate';
import { CertificateBase } from './certificate-base';
/**
 * (experimental) Properties for your private certificate.
 *
 * @experimental
 */
export interface PrivateCertificateProps {
    /**
     * (experimental) Fully-qualified domain name to request a private certificate for.
     *
     * May contain wildcards, such as ``*.domain.com``.
     *
     * @experimental
     */
    readonly domainName: string;
    /**
     * (experimental) Alternative domain names on your private certificate.
     *
     * Use this to register alternative domain names that represent the same site.
     *
     * @default - No additional FQDNs will be included as alternative domain names.
     * @experimental
     */
    readonly subjectAlternativeNames?: string[];
    /**
     * (experimental) Private certificate authority (CA) that will be used to issue the certificate.
     *
     * @experimental
     */
    readonly certificateAuthority: acmpca.ICertificateAuthority;
}
/**
 * (experimental) A private certificate managed by AWS Certificate Manager.
 *
 * @experimental
 * @resource AWS::CertificateManager::Certificate
 */
export declare class PrivateCertificate extends CertificateBase implements ICertificate {
    /**
     * (experimental) Import a certificate.
     *
     * @experimental
     */
    static fromCertificateArn(scope: Construct, id: string, certificateArn: string): ICertificate;
    /**
     * (experimental) The certificate's ARN.
     *
     * @experimental
     */
    readonly certificateArn: string;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: PrivateCertificateProps);
}
