import * as codepipeline from '../../../aws-codepipeline';
import { Action } from '../action';
import { Construct } from '../../../core';
/**
 * (experimental) Construction properties for {@link CodeStarConnectionsSourceAction}.
 *
 * @experimental
 */
export interface CodeStarConnectionsSourceActionProps extends codepipeline.CommonAwsActionProps {
    /**
     * (experimental) The output artifact that this action produces.
     *
     * Can be used as input for further pipeline actions.
     *
     * @experimental
     */
    readonly output: codepipeline.Artifact;
    /**
     * (experimental) The ARN of the CodeStar Connection created in the AWS console that has permissions to access this GitHub or BitBucket repository.
     *
     * @see https://docs.aws.amazon.com/codepipeline/latest/userguide/connections-create.html
     * @experimental
     * @example
     *
     * 'arn:aws:codestar-connections:us-east-1:123456789012:connection/12345678-abcd-12ab-34cdef5678gh'
     */
    readonly connectionArn: string;
    /**
     * (experimental) The owning user or organization of the repository.
     *
     * @experimental
     * @example
     *
     * 'aws'
     */
    readonly owner: string;
    /**
     * (experimental) The name of the repository.
     *
     * @experimental
     * @example
     *
     * 'aws-cdk'
     */
    readonly repo: string;
    /**
     * (experimental) The branch to build.
     *
     * @default 'master'
     * @experimental
     */
    readonly branch?: string;
    /**
     * (experimental) Whether the output should be the contents of the repository (which is the default), or a link that allows CodeBuild to clone the repository before building.
     *
     * **Note**: if this option is true,
     * then only CodeBuild actions can use the resulting {@link output}.
     *
     * @default false
     * @see https://docs.aws.amazon.com/codepipeline/latest/userguide/action-reference-CodestarConnectionSource.html#action-reference-CodestarConnectionSource-config
     * @experimental
     */
    readonly codeBuildCloneOutput?: boolean;
    /**
     * (experimental) Controls automatically starting your pipeline when a new commit is made on the configured repository and branch.
     *
     * If unspecified,
     * the default value is true, and the field does not display by default.
     *
     * @default true
     * @see https://docs.aws.amazon.com/codepipeline/latest/userguide/action-reference-CodestarConnectionSource.html
     * @experimental
     */
    readonly triggerOnPush?: boolean;
}
/**
 * (experimental) A CodePipeline source action for the CodeStar Connections source, which allows connecting to GitHub and BitBucket.
 *
 * @experimental
 */
export declare class CodeStarConnectionsSourceAction extends Action {
    /**
     * The name of the property that holds the ARN of the CodeStar Connection
     * inside of the CodePipeline Artifact's metadata.
     *
     * @internal
     */
    static readonly _CONNECTION_ARN_PROPERTY = "CodeStarConnectionArnProperty";
    private readonly props;
    /**
     * @experimental
     */
    constructor(props: CodeStarConnectionsSourceActionProps);
    /**
     * (experimental) This is a renamed version of the {@link IAction.bind} method.
     *
     * @experimental
     */
    protected bound(_scope: Construct, _stage: codepipeline.IStage, options: codepipeline.ActionBindOptions): codepipeline.ActionConfig;
}
