import * as ecr from '../../aws-ecr';
import { Construct } from 'constructs';
import { IAsset } from '../../assets';
import { Construct as CoreConstruct } from '../../core';
/**
 * (experimental) Options for TarballImageAsset.
 *
 * @experimental
 */
export interface TarballImageAssetProps {
    /**
     * (experimental) Absolute path to the tarball.
     *
     * It is recommended to to use the script running directory (e.g. `__dirname`
     * in Node.js projects or dirname of `__file__` in Python) if your tarball
     * is located as a resource inside your project.
     *
     * @experimental
     */
    readonly tarballFile: string;
}
/**
 * (experimental) An asset that represents a Docker image.
 *
 * The image will loaded from an existing tarball and uploaded to an ECR repository.
 *
 * @experimental
 */
export declare class TarballImageAsset extends CoreConstruct implements IAsset {
    /**
     * (experimental) The full URI of the image (including a tag).
     *
     * Use this reference to pull
     * the asset.
     *
     * @experimental
     */
    imageUri: string;
    /**
     * (experimental) Repository where the image is stored.
     *
     * @experimental
     */
    repository: ecr.IRepository;
    /**
     * (deprecated) A hash of the source of this asset, which is available at construction time.
     *
     * As this is a plain
     * string, it can be used in construct IDs in order to enforce creation of a new resource when
     * the content hash has changed.
     *
     * @deprecated use assetHash
     */
    readonly sourceHash: string;
    /**
     * (experimental) A hash of this asset, which is available at construction time.
     *
     * As this is a plain string, it
     * can be used in construct IDs in order to enforce creation of a new resource when the content
     * hash has changed.
     *
     * @experimental
     */
    readonly assetHash: string;
    /**
     * @experimental
     */
    constructor(scope: Construct, id: string, props: TarballImageAssetProps);
}
