import * as events from '../../aws-events';
import * as iam from '../../aws-iam';
import * as sqs from '../../aws-sqs';
/**
 * (experimental) Configuration properties of an Event Bus event.
 *
 * Cannot extend TargetBaseProps. Retry policy is not supported for Event bus targets.
 *
 * @experimental
 */
export interface EventBusProps {
    /**
     * (experimental) Role to be used to publish the event.
     *
     * @default a new role is created.
     * @experimental
     */
    readonly role?: iam.IRole;
    /**
     * (experimental) The SQS queue to be used as deadLetterQueue. Check out the [considerations for using a dead-letter queue](https://docs.aws.amazon.com/eventbridge/latest/userguide/rule-dlq.html#dlq-considerations).
     *
     * The events not successfully delivered are automatically retried for a specified period of time,
     * depending on the retry policy of the target.
     * If an event is not delivered before all retry attempts are exhausted, it will be sent to the dead letter queue.
     *
     * @default - no dead-letter queue
     * @experimental
     */
    readonly deadLetterQueue?: sqs.IQueue;
}
/**
 * (experimental) Notify an existing Event Bus of an event.
 *
 * @experimental
 */
export declare class EventBus implements events.IRuleTarget {
    private readonly eventBus;
    private readonly props;
    /**
     * @experimental
     */
    constructor(eventBus: events.IEventBus, props?: EventBusProps);
    /**
     * (experimental) Returns the rule target specification.
     *
     * NOTE: Do not use the various `inputXxx` options. They can be set in a call to `addTarget`.
     *
     * @experimental
     */
    bind(rule: events.IRule, _id?: string): events.RuleTargetConfig;
    private putEventStatement;
}
