import * as codebuild from '../../../../aws-codebuild';
import * as codepipeline from '../../../../aws-codepipeline';
import * as ec2 from '../../../../aws-ec2';
import * as events from '../../../../aws-events';
import * as iam from '../../../../aws-iam';
import { DockerCredential } from '../../docker-credentials';
import { Construct } from '../../../../core';
/**
 * (deprecated) Configuration options for a SimpleSynth.
 *
 * @deprecated This class is part of the old API. Use the API based on the `CodePipeline` class instead
 */
export interface SimpleSynthOptions {
    /**
     * (deprecated) The source artifact of the CodePipeline.
     *
     * @deprecated
     */
    readonly sourceArtifact: codepipeline.Artifact;
    /**
     * (deprecated) The artifact where the CloudAssembly should be emitted.
     *
     * @deprecated
     */
    readonly cloudAssemblyArtifact: codepipeline.Artifact;
    /**
     * (deprecated) Environment variables to send into build.
     *
     * NOTE: You may run into the 1000-character limit for the Action configuration if you have a large
     * number of variables or if their names or values are very long.
     * If you do, pass them to the underlying CodeBuild project directly in `environment` instead.
     * However, you will not be able to use CodePipeline Variables in this case.
     *
     * @default - No additional environment variables
     * @deprecated
     */
    readonly environmentVariables?: Record<string, codebuild.BuildEnvironmentVariable>;
    /**
     * (deprecated) Environment variables to copy over from parent env.
     *
     * These are environment variables that are being used by the build.
     *
     * @default - No environment variables copied
     * @deprecated
     */
    readonly copyEnvironmentVariables?: string[];
    /**
     * (deprecated) Name of the build action.
     *
     * @default 'Synth'
     * @deprecated
     */
    readonly actionName?: string;
    /**
     * (deprecated) Name of the CodeBuild project.
     *
     * @default - Automatically generated
     * @deprecated
     */
    readonly projectName?: string;
    /**
     * (deprecated) Build environment to use for CodeBuild job.
     *
     * @default BuildEnvironment.LinuxBuildImage.STANDARD_5_0
     * @deprecated
     */
    readonly environment?: codebuild.BuildEnvironment;
    /**
     * (deprecated) Directory inside the source where package.json and cdk.json are located.
     *
     * @default - Repository root
     * @deprecated
     */
    readonly subdirectory?: string;
    /**
     * (deprecated) Produce additional output artifacts after the build based on the given directories.
     *
     * Can be used to produce additional artifacts during the build step,
     * separate from the cloud assembly, which can be used further on in the
     * pipeline.
     *
     * Directories are evaluated with respect to `subdirectory`.
     *
     * @default - No additional artifacts generated
     * @deprecated
     */
    readonly additionalArtifacts?: AdditionalArtifact[];
    /**
     * (deprecated) Policy statements to add to role used during the synth.
     *
     * Can be used to add acces to a CodeArtifact repository etc.
     *
     * @default - No policy statements added to CodeBuild Project Role
     * @deprecated
     */
    readonly rolePolicyStatements?: iam.PolicyStatement[];
    /**
     * (deprecated) The VPC where to execute the SimpleSynth.
     *
     * @default - No VPC
     * @deprecated
     */
    readonly vpc?: ec2.IVpc;
    /**
     * (deprecated) Which subnets to use.
     *
     * Only used if 'vpc' is supplied.
     *
     * @default - All private subnets.
     * @deprecated
     */
    readonly subnetSelection?: ec2.SubnetSelection;
    /**
     * (deprecated) custom BuildSpec that is merged with the generated one.
     *
     * @default - none
     * @deprecated
     */
    readonly buildSpec?: codebuild.BuildSpec;
}
/**
 * (deprecated) Construction props for SimpleSynthAction.
 *
 * @deprecated This class is part of the old API. Use the API based on the `CodePipeline` class instead
 */
export interface SimpleSynthActionProps extends SimpleSynthOptions {
    /**
     * (deprecated) The synth command.
     *
     * @deprecated
     */
    readonly synthCommand: string;
    /**
     * (deprecated) The install command.
     *
     * If not provided by the build image or another dependency
     * management tool, at least install the CDK CLI here using
     * `npm install -g aws-cdk`.
     *
     * @default - No install required
     * @deprecated Use `installCommands` instead
     */
    readonly installCommand?: string;
    /**
     * (deprecated) The build command.
     *
     * If your programming language requires a compilation step, put the
     * compilation command here.
     *
     * @default - No build required
     * @deprecated Use `buildCommands` instead
     */
    readonly buildCommand?: string;
    /**
     * (deprecated) Install commands.
     *
     * If not provided by the build image or another dependency
     * management tool, at least install the CDK CLI here using
     * `npm install -g aws-cdk`.
     *
     * @default - No install required
     * @deprecated
     */
    readonly installCommands?: string[];
    /**
     * (deprecated) The build commands.
     *
     * If your programming language requires a compilation step, put the
     * compilation command here.
     *
     * @default - No build required
     * @deprecated
     */
    readonly buildCommands?: string[];
    /**
     * (deprecated) Test commands.
     *
     * These commands are run after the build commands but before the
     * synth command.
     *
     * @default - No test commands
     * @deprecated
     */
    readonly testCommands?: string[];
}
/**
 * (deprecated) Specification of an additional artifact to generate.
 *
 * @deprecated This class is part of the old API. Use the API based on the `CodePipeline` class instead
 */
export interface AdditionalArtifact {
    /**
     * (deprecated) Directory to be packaged.
     *
     * @deprecated
     */
    readonly directory: string;
    /**
     * (deprecated) Artifact to represent the build directory in the pipeline.
     *
     * @deprecated
     */
    readonly artifact: codepipeline.Artifact;
}
/**
 * (deprecated) A standard synth with a generated buildspec.
 *
 * @deprecated This class is part of the old API. Use the API based on the `CodePipeline` class instead
 */
export declare class SimpleSynthAction implements codepipeline.IAction, iam.IGrantable {
    private readonly props;
    /**
     * (deprecated) Create a standard NPM synth action.
     *
     * Uses `npm ci` to install dependencies and `npx cdk synth` to synthesize.
     *
     * If you need a build step, add `buildCommand: 'npm run build'`.
     *
     * @deprecated
     */
    static standardNpmSynth(options: StandardNpmSynthOptions): SimpleSynthAction;
    /**
     * (deprecated) Create a standard Yarn synth action.
     *
     * Uses `yarn install --frozen-lockfile` to install dependencies and `npx cdk synth` to synthesize.
     *
     * If you need a build step, add `buildCommand: 'yarn build'`.
     *
     * @deprecated
     */
    static standardYarnSynth(options: StandardYarnSynthOptions): SimpleSynthAction;
    private _action?;
    private _actionProperties;
    private _project?;
    private _dockerCredentials?;
    /**
     * @deprecated
     */
    constructor(props: SimpleSynthActionProps);
    /**
     * (deprecated) Exists to implement IAction.
     *
     * @deprecated
     */
    get actionProperties(): codepipeline.ActionProperties;
    /**
     * (deprecated) Project generated to run the synth command.
     *
     * @deprecated
     */
    get project(): codebuild.IProject;
    /**
     * (deprecated) Exists to implement IAction.
     *
     * @deprecated
     */
    bind(scope: Construct, stage: codepipeline.IStage, options: codepipeline.ActionBindOptions): codepipeline.ActionConfig;
    /**
     * (deprecated) The CodeBuild Project's principal.
     *
     * @deprecated
     */
    get grantPrincipal(): iam.IPrincipal;
    /**
     * (deprecated) Exists to implement IAction.
     *
     * @deprecated
     */
    onStateChange(name: string, target?: events.IRuleTarget, options?: events.RuleProps): events.Rule;
    /**
     * Associate one or more Docker registries and associated credentials with the synth action.
     * This will be used to inject installation commands to set up `cdk-assets`,
     * and grant read access to the credentials.
     * @internal
     */
    _addDockerCredentials(dockerCredentials: DockerCredential[]): void;
}
/**
 * (deprecated) Options for a convention-based synth using NPM.
 *
 * @deprecated This class is part of the old API. Use the API based on the `CodePipeline` class instead
 */
export interface StandardNpmSynthOptions extends SimpleSynthOptions {
    /**
     * (deprecated) The install command.
     *
     * @default 'npm ci'
     * @deprecated
     */
    readonly installCommand?: string;
    /**
     * (deprecated) The build command.
     *
     * By default, we assume NPM projects are either written in JavaScript or are
     * using `ts-node`, so don't need a build command.
     *
     * Otherwise, put the build command here, for example `npm run build`.
     *
     * @default - No build required
     * @deprecated
     */
    readonly buildCommand?: string;
    /**
     * (deprecated) The synth command.
     *
     * @default 'npx cdk synth'
     * @deprecated
     */
    readonly synthCommand?: string;
    /**
     * (deprecated) Test commands.
     *
     * These commands are run after the build commands but before the
     * synth command.
     *
     * @default - No test commands
     * @deprecated
     */
    readonly testCommands?: string[];
}
/**
 * (deprecated) Options for a convention-based synth using Yarn.
 *
 * @deprecated This class is part of the old API. Use the API based on the `CodePipeline` class instead
 */
export interface StandardYarnSynthOptions extends SimpleSynthOptions {
    /**
     * (deprecated) The install command.
     *
     * @default 'yarn install --frozen-lockfile'
     * @deprecated
     */
    readonly installCommand?: string;
    /**
     * (deprecated) The build command.
     *
     * By default, we assume NPM projects are either written in JavaScript or are
     * using `ts-node`, so don't need a build command.
     *
     * Otherwise, put the build command here, for example `npm run build`.
     *
     * @default - No build required
     * @deprecated
     */
    readonly buildCommand?: string;
    /**
     * (deprecated) The synth command.
     *
     * @default 'npx cdk synth'
     * @deprecated
     */
    readonly synthCommand?: string;
    /**
     * (deprecated) Test commands.
     *
     * These commands are run after the build commands but before the
     * synth command.
     *
     * @default - No test commands
     * @deprecated
     */
    readonly testCommands?: string[];
}
